.. rst-class:: detail

StartWatch
=====================

.. currentmodule:: compas_rrc

.. autoclass:: StartWatch

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~StartWatch.__init__
        ~StartWatch.from_msg
    
    